from x_mock.m_mock import m_mock


def execute(params):
    print(f'm_mock.mock("{params}"):{m_mock.mock(params)}')


def execute_ran(params):
    print(f'm_mock.mock("{params}"):{m_mock.mock(params)}')
